# Fake Dataset


[![image](https://img.shields.io/pypi/v/fake_dataset.svg)](https://pypi.python.org/pypi/fake_dataset)


**Toolkit for generating fake datasets.**


-   Free software: MIT license
-   Documentation: https://matheusfsa.github.io/fake_dataset
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
